package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.Wallet;

/**
 * 钱包Service接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface IWalletService 
{
    /**
     * 查询钱包
     * 
     * @param id 钱包主键
     * @return 钱包
     */
    public Wallet selectWalletById(Long id);

    /**
     * 查询钱包列表
     * 
     * @param wallet 钱包
     * @return 钱包集合
     */
    public List<Wallet> selectWalletList(Wallet wallet);

    /**
     * 新增钱包
     * 
     * @param wallet 钱包
     * @return 结果
     */
    public int insertWallet(Wallet wallet);

    /**
     * 修改钱包
     * 
     * @param wallet 钱包
     * @return 结果
     */
    public int updateWallet(Wallet wallet);

    /**
     * 批量删除钱包
     * 
     * @param ids 需要删除的钱包主键集合
     * @return 结果
     */
    public int deleteWalletByIds(Long[] ids);

    /**
     * 删除钱包信息
     * 
     * @param id 钱包主键
     * @return 结果
     */
    public int deleteWalletById(Long id);

    /**
     * 查询钱包列表
     *
     * @return 钱包集合
     */
    public List<Wallet> getWalletList();
}
